--
-- PostgreSQL database dump
--

SET client_encoding = 'LATIN1';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

--
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: nac
--

CREATE PROCEDURAL LANGUAGE plpgsql;


ALTER PROCEDURAL LANGUAGE plpgsql OWNER TO nac;

SET search_path = public, pg_catalog;

--
-- Name: bigint2inet(bigint); Type: FUNCTION; Schema: public; Owner: nac
--

CREATE FUNCTION bigint2inet(bigint) RETURNS inet
    AS $_$
BEGIN
   RETURN cidr('0x' || lpad(to_hex($1), 8, '0'));
END;
$_$
    LANGUAGE plpgsql IMMUTABLE STRICT;


ALTER FUNCTION public.bigint2inet(bigint) OWNER TO nac;

--
-- Name: juezviolaciones(); Type: FUNCTION; Schema: public; Owner: nac
--

CREATE FUNCTION juezviolaciones() RETURNS trigger
    AS $$

DECLARE
   existe_politica	boolean;
   sig		  	bigint;

BEGIN

   -- Primero ver si alguna politica aplica
   -- si no, ni caso tiene seguir
   SELECT INTO sig sig_sid
          FROM signature
          WHERE signature.sig_id = NEW.signature;

   SELECT INTO existe_politica true
          FROM politicas
          WHERE politicas.signature = sig;

   IF existe_politica IS NOT NULL THEN


      -- Y reportamos una violacion
      INSERT INTO violaciones
             VALUES(DEFAULT,
                    sig,
                    'f',
                    NEW.cid,
                    't',
                    NEW.sid);
   END IF;

   RETURN NEW;
END;
$$
    LANGUAGE plpgsql;


ALTER FUNCTION public.juezviolaciones() OWNER TO nac;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: acid_ag; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE acid_ag (
    ag_id integer NOT NULL,
    ag_name text,
    ag_desc text,
    ag_ctime timestamp without time zone,
    ag_ltime timestamp without time zone
);


ALTER TABLE public.acid_ag OWNER TO nac;

--
-- Name: acid_ag_ag_id_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE acid_ag_ag_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.acid_ag_ag_id_seq OWNER TO nac;

--
-- Name: acid_ag_ag_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE acid_ag_ag_id_seq OWNED BY acid_ag.ag_id;


--
-- Name: acid_ag_alert; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE acid_ag_alert (
    ag_id bigint NOT NULL,
    ag_sid integer NOT NULL,
    ag_cid bigint NOT NULL
);


ALTER TABLE public.acid_ag_alert OWNER TO nac;

--
-- Name: acid_event; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE acid_event (
    sid bigint NOT NULL,
    cid bigint NOT NULL,
    signature text NOT NULL,
    sig_name text,
    sig_class_id bigint,
    sig_priority bigint,
    "timestamp" timestamp without time zone NOT NULL,
    ip_src bigint,
    ip_dst bigint,
    ip_proto integer,
    layer4_sport integer,
    layer4_dport integer
);


ALTER TABLE public.acid_event OWNER TO nac;

--
-- Name: acid_ip_cache; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE acid_ip_cache (
    ipc_ip bigint NOT NULL,
    ipc_fqdn text,
    ipc_dns_timestamp timestamp without time zone,
    ipc_whois text,
    ipc_whois_timestamp timestamp without time zone
);


ALTER TABLE public.acid_ip_cache OWNER TO nac;

--
-- Name: base_roles; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE base_roles (
    role_id bigint NOT NULL,
    role_name text,
    role_desc text
);


ALTER TABLE public.base_roles OWNER TO nac;

--
-- Name: base_users; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE base_users (
    usr_id bigint NOT NULL,
    usr_login text NOT NULL,
    usr_pwd text NOT NULL,
    usr_name text NOT NULL,
    role_id bigint NOT NULL,
    usr_enabled bigint NOT NULL
);


ALTER TABLE public.base_users OWNER TO nac;

--
-- Name: castigos; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE castigos (
    id_castigo integer NOT NULL,
    descripcion text NOT NULL,
    comando text NOT NULL
);


ALTER TABLE public.castigos OWNER TO nac;

--
-- Name: TABLE castigos; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON TABLE castigos IS 'Castigos para las violaciones junto con su descripcion y el comando a ejecutar por cada uno.
';


--
-- Name: castigos_id_castigo_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE castigos_id_castigo_seq
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.castigos_id_castigo_seq OWNER TO nac;

--
-- Name: castigos_id_castigo_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE castigos_id_castigo_seq OWNED BY castigos.id_castigo;


--
-- Name: data; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE data (
    sid integer NOT NULL,
    cid bigint NOT NULL,
    data_payload text
);


ALTER TABLE public.data OWNER TO nac;

--
-- Name: detail; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE detail (
    detail_type smallint NOT NULL,
    detail_text text NOT NULL
);


ALTER TABLE public.detail OWNER TO nac;

--
-- Name: encoding; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE encoding (
    encoding_type smallint NOT NULL,
    encoding_text text NOT NULL
);


ALTER TABLE public.encoding OWNER TO nac;

--
-- Name: event; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE event (
    sid integer NOT NULL,
    cid bigint NOT NULL,
    signature integer NOT NULL,
    "timestamp" timestamp with time zone NOT NULL
);


ALTER TABLE public.event OWNER TO nac;

--
-- Name: icmphdr; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE icmphdr (
    sid integer NOT NULL,
    cid bigint NOT NULL,
    icmp_type smallint NOT NULL,
    icmp_code smallint NOT NULL,
    icmp_csum integer,
    icmp_id integer,
    icmp_seq integer
);


ALTER TABLE public.icmphdr OWNER TO nac;

--
-- Name: iphdr; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE iphdr (
    sid integer NOT NULL,
    cid bigint NOT NULL,
    ip_src bigint NOT NULL,
    ip_dst bigint NOT NULL,
    ip_ver smallint,
    ip_hlen smallint,
    ip_tos smallint,
    ip_len integer,
    ip_id integer,
    ip_flags smallint,
    ip_off integer,
    ip_ttl smallint,
    ip_proto smallint NOT NULL,
    ip_csum integer
);


ALTER TABLE public.iphdr OWNER TO nac;

--
-- Name: opt; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE opt (
    sid integer NOT NULL,
    cid bigint NOT NULL,
    optid smallint NOT NULL,
    opt_proto smallint NOT NULL,
    opt_code smallint NOT NULL,
    opt_len integer,
    opt_data text
);


ALTER TABLE public.opt OWNER TO nac;

--
-- Name: politicas; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE politicas (
    id_politica integer NOT NULL,
    signature integer NOT NULL,
    id_castigo integer NOT NULL,
    tipo_usuario integer DEFAULT 1 NOT NULL
);


ALTER TABLE public.politicas OWNER TO nac;

--
-- Name: TABLE politicas; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON TABLE politicas IS 'Establece el castigo que se aplicara para cada violacion.

Las signatures que aparezcan aqui se consideraran como violaciones y aqui mismo se ve que castigo aplicar. Si se levanta una alerta cuya signature no esta en la lista de politicas, se asume que no requiere accion por parte del ejecutor.

Los castigos pueden ser quitar el acceso, solo alertar al administrador, restablecer el acceso (La famosa "violacion negativa", etc. Estan definidos en la tabla "castigos".

Las politicas son por tipo de usuario. Puede haber varios castigos diferentes para la misma politica, dependiendo del tipo al que pertenece el usuario que la comete.

';


--
-- Name: politicas_id_politica_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE politicas_id_politica_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.politicas_id_politica_seq OWNER TO nac;

--
-- Name: politicas_id_politica_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE politicas_id_politica_seq OWNED BY politicas.id_politica;


--
-- Name: reference; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE reference (
    ref_id integer NOT NULL,
    ref_system_id integer NOT NULL,
    ref_tag text NOT NULL
);


ALTER TABLE public.reference OWNER TO nac;

--
-- Name: reference_ref_id_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE reference_ref_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.reference_ref_id_seq OWNER TO nac;

--
-- Name: reference_ref_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE reference_ref_id_seq OWNED BY reference.ref_id;


--
-- Name: reference_system; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE reference_system (
    ref_system_id integer NOT NULL,
    ref_system_name text
);


ALTER TABLE public.reference_system OWNER TO nac;

--
-- Name: reference_system_ref_system_id_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE reference_system_ref_system_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.reference_system_ref_system_id_seq OWNER TO nac;

--
-- Name: reference_system_ref_system_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE reference_system_ref_system_id_seq OWNED BY reference_system.ref_system_id;


--
-- Name: schema; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE schema (
    vseq integer NOT NULL,
    ctime timestamp with time zone NOT NULL
);


ALTER TABLE public.schema OWNER TO nac;

--
-- Name: sensor; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE sensor (
    sid integer NOT NULL,
    hostname text,
    interface text,
    filter text,
    detail smallint,
    encoding smallint,
    last_cid bigint NOT NULL
);


ALTER TABLE public.sensor OWNER TO nac;

--
-- Name: sensor_sid_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE sensor_sid_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.sensor_sid_seq OWNER TO nac;

--
-- Name: sensor_sid_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE sensor_sid_seq OWNED BY sensor.sid;


--
-- Name: sig_class; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE sig_class (
    sig_class_id integer NOT NULL,
    sig_class_name text NOT NULL
);


ALTER TABLE public.sig_class OWNER TO nac;

--
-- Name: sig_class_sig_class_id_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE sig_class_sig_class_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.sig_class_sig_class_id_seq OWNER TO nac;

--
-- Name: sig_class_sig_class_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE sig_class_sig_class_id_seq OWNED BY sig_class.sig_class_id;


--
-- Name: sig_reference; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE sig_reference (
    sig_id integer NOT NULL,
    ref_seq integer NOT NULL,
    ref_id integer NOT NULL
);


ALTER TABLE public.sig_reference OWNER TO nac;

--
-- Name: signature; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE signature (
    sig_id integer NOT NULL,
    sig_name text NOT NULL,
    sig_class_id bigint,
    sig_priority bigint,
    sig_rev bigint,
    sig_sid bigint,
    sig_gid bigint
);


ALTER TABLE public.signature OWNER TO nac;

--
-- Name: signature_sig_id_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE signature_sig_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;

ALTER SEQUENCE signature_sig_id_seq start 2;

ALTER TABLE public.signature_sig_id_seq OWNER TO nac;

--
-- Name: signature_sig_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE signature_sig_id_seq OWNED BY signature.sig_id;

--
-- Data for Name: signature; Type: TABLE DATA; Schema: public; Owner: nac
--

COPY signature (sig_id, sig_name, sig_class_id, sig_priority, sig_rev, sig_sid, sig_gid) FROM stdin;
1	Reactivacion	1	\N	\N	3000001	\N
\.

--
-- Name: tcphdr; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE tcphdr (
    sid integer NOT NULL,
    cid bigint NOT NULL,
    tcp_sport integer NOT NULL,
    tcp_dport integer NOT NULL,
    tcp_seq bigint,
    tcp_ack bigint,
    tcp_off smallint,
    tcp_res smallint,
    tcp_flags smallint NOT NULL,
    tcp_win integer,
    tcp_csum integer,
    tcp_urp integer
);


ALTER TABLE public.tcphdr OWNER TO nac;

--
-- Name: tipos_usuarios; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE tipos_usuarios (
    tipo_usuario integer NOT NULL,
    descripcion text NOT NULL
);


ALTER TABLE public.tipos_usuarios OWNER TO nac;

--
-- Name: TABLE tipos_usuarios; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON TABLE tipos_usuarios IS 'Los diferentes tipos de usuarios: todos, administradores, usuarios comunes, etc.
';

--
-- Data for Name: tipos_usuarios; Type: TABLE DATA; Schema: public; Owner: nac
--

INSERT INTO tipos_usuarios VALUES (3, 'Administradores');
INSERT INTO tipos_usuarios VALUES (1, 'Todos');
INSERT INTO tipos_usuarios VALUES (2, 'Usuarios');




--
-- Name: udphdr; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE udphdr (
    sid integer NOT NULL,
    cid bigint NOT NULL,
    udp_sport integer NOT NULL,
    udp_dport integer NOT NULL,
    udp_len integer,
    udp_csum integer
);


ALTER TABLE public.udphdr OWNER TO nac;

--
-- Name: usuarios; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE usuarios (
    id_usuario inet NOT NULL,
    tipo_usuario integer DEFAULT 1 NOT NULL,
    oportunidades integer NOT NULL
);


ALTER TABLE public.usuarios OWNER TO nac;

--
-- Name: TABLE usuarios; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON TABLE usuarios IS 'Usuarios, tipo de usuarios y las oportunidades que les quedan ';


--
-- Name: COLUMN usuarios.oportunidades; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON COLUMN usuarios.oportunidades IS 'Las oportunidades para restaurar su acceso que le quedan al usuario.
';


--
-- Name: violaciones; Type: TABLE; Schema: public; Owner: nac; Tablespace: 
--

CREATE TABLE violaciones (
    id_violacion integer NOT NULL,
    signature bigint NOT NULL,
    ejecutada boolean NOT NULL,
    cid bigint,
    activa boolean DEFAULT true NOT NULL,
    sid integer
);


ALTER TABLE public.violaciones OWNER TO nac;

--
-- Name: TABLE violaciones; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON TABLE violaciones IS 'Violaciones encontradas por el juez de violaciones (Usuario "x" levanto la alerta "y")
';


--
-- Name: COLUMN violaciones.signature; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON COLUMN violaciones.signature IS 'El ID de la signature relacionada';


--
-- Name: COLUMN violaciones.ejecutada; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON COLUMN violaciones.ejecutada IS 'Indica si el castigo para esta violacion ya fue llevado a cabo.
';


--
-- Name: COLUMN violaciones.sid; Type: COMMENT; Schema: public; Owner: nac
--

COMMENT ON COLUMN violaciones.sid IS 'El ID del sensor que registro este evento';


--
-- Name: violaciones_id_violacion_seq; Type: SEQUENCE; Schema: public; Owner: nac
--

CREATE SEQUENCE violaciones_id_violacion_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.violaciones_id_violacion_seq OWNER TO nac;

--
-- Name: violaciones_id_violacion_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: nac
--

ALTER SEQUENCE violaciones_id_violacion_seq OWNED BY violaciones.id_violacion;


--
-- Name: ag_id; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE acid_ag ALTER COLUMN ag_id SET DEFAULT nextval('acid_ag_ag_id_seq'::regclass);


--
-- Name: id_castigo; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE castigos ALTER COLUMN id_castigo SET DEFAULT nextval('castigos_id_castigo_seq'::regclass);


--
-- Name: id_politica; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE politicas ALTER COLUMN id_politica SET DEFAULT nextval('politicas_id_politica_seq'::regclass);


--
-- Name: ref_id; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE reference ALTER COLUMN ref_id SET DEFAULT nextval('reference_ref_id_seq'::regclass);


--
-- Name: ref_system_id; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE reference_system ALTER COLUMN ref_system_id SET DEFAULT nextval('reference_system_ref_system_id_seq'::regclass);


--
-- Name: sid; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE sensor ALTER COLUMN sid SET DEFAULT nextval('sensor_sid_seq'::regclass);


--
-- Name: sig_class_id; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE sig_class ALTER COLUMN sig_class_id SET DEFAULT nextval('sig_class_sig_class_id_seq'::regclass);


--
-- Name: sig_id; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE signature ALTER COLUMN sig_id SET DEFAULT nextval('signature_sig_id_seq'::regclass);


--
-- Name: id_violacion; Type: DEFAULT; Schema: public; Owner: nac
--

ALTER TABLE violaciones ALTER COLUMN id_violacion SET DEFAULT nextval('violaciones_id_violacion_seq'::regclass);


--
-- Name: acid_ag_alert_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY acid_ag_alert
    ADD CONSTRAINT acid_ag_alert_pkey PRIMARY KEY (ag_id, ag_sid, ag_cid);


--
-- Name: acid_ag_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY acid_ag
    ADD CONSTRAINT acid_ag_pkey PRIMARY KEY (ag_id);


--
-- Name: acid_event_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY acid_event
    ADD CONSTRAINT acid_event_pkey PRIMARY KEY (sid, cid);


--
-- Name: acid_ip_cache_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY acid_ip_cache
    ADD CONSTRAINT acid_ip_cache_pkey PRIMARY KEY (ipc_ip);


--
-- Name: base_roles_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY base_roles
    ADD CONSTRAINT base_roles_pkey PRIMARY KEY (role_id);


--
-- Name: base_users_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY base_users
    ADD CONSTRAINT base_users_pkey PRIMARY KEY (usr_id);


--
-- Name: data_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY data
    ADD CONSTRAINT data_pkey PRIMARY KEY (sid, cid);


--
-- Name: detail_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY detail
    ADD CONSTRAINT detail_pkey PRIMARY KEY (detail_type);


--
-- Name: encoding_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY encoding
    ADD CONSTRAINT encoding_pkey PRIMARY KEY (encoding_type);


--
-- Name: event_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY event
    ADD CONSTRAINT event_pkey PRIMARY KEY (sid, cid);


--
-- Name: icmphdr_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY icmphdr
    ADD CONSTRAINT icmphdr_pkey PRIMARY KEY (sid, cid);


--
-- Name: id_castigo; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY castigos
    ADD CONSTRAINT id_castigo PRIMARY KEY (id_castigo);


--
-- Name: id_politica; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY politicas
    ADD CONSTRAINT id_politica PRIMARY KEY (id_politica);


--
-- Name: id_usuario; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY usuarios
    ADD CONSTRAINT id_usuario PRIMARY KEY (id_usuario);


--
-- Name: id_violacion; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY violaciones
    ADD CONSTRAINT id_violacion PRIMARY KEY (id_violacion);


--
-- Name: iphdr_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY iphdr
    ADD CONSTRAINT iphdr_pkey PRIMARY KEY (sid, cid);


--
-- Name: opt_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY opt
    ADD CONSTRAINT opt_pkey PRIMARY KEY (sid, cid, optid);


--
-- Name: reference_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY reference
    ADD CONSTRAINT reference_pkey PRIMARY KEY (ref_id);


--
-- Name: reference_system_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY reference_system
    ADD CONSTRAINT reference_system_pkey PRIMARY KEY (ref_system_id);


--
-- Name: schema_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY schema
    ADD CONSTRAINT schema_pkey PRIMARY KEY (vseq);


--
-- Name: sensor_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY sensor
    ADD CONSTRAINT sensor_pkey PRIMARY KEY (sid);


--
-- Name: sig_class_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY sig_class
    ADD CONSTRAINT sig_class_pkey PRIMARY KEY (sig_class_id);


--
-- Name: sig_reference_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY sig_reference
    ADD CONSTRAINT sig_reference_pkey PRIMARY KEY (sig_id, ref_seq);


--
-- Name: signature_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY signature
    ADD CONSTRAINT signature_pkey PRIMARY KEY (sig_id);


--
-- Name: tcphdr_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY tcphdr
    ADD CONSTRAINT tcphdr_pkey PRIMARY KEY (sid, cid);


--
-- Name: tipo_usuario; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY tipos_usuarios
    ADD CONSTRAINT tipo_usuario PRIMARY KEY (tipo_usuario);


--
-- Name: udphdr_pkey; Type: CONSTRAINT; Schema: public; Owner: nac; Tablespace: 
--

ALTER TABLE ONLY udphdr
    ADD CONSTRAINT udphdr_pkey PRIMARY KEY (sid, cid);


--
-- Name: acid_ag_alert_aid_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_ag_alert_aid_idx ON acid_ag_alert USING btree (ag_id);


--
-- Name: acid_ag_alert_id_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_ag_alert_id_idx ON acid_ag_alert USING btree (ag_sid, ag_cid);


--
-- Name: acid_event_ip_dst; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_ip_dst ON acid_event USING btree (ip_dst);


--
-- Name: acid_event_ip_proto; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_ip_proto ON acid_event USING btree (ip_proto);


--
-- Name: acid_event_ip_src; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_ip_src ON acid_event USING btree (ip_src);


--
-- Name: acid_event_layer4_dport; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_layer4_dport ON acid_event USING btree (layer4_dport);


--
-- Name: acid_event_layer4_sport; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_layer4_sport ON acid_event USING btree (layer4_sport);


--
-- Name: acid_event_sig_class_id; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_sig_class_id ON acid_event USING btree (sig_class_id);


--
-- Name: acid_event_sig_name; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_sig_name ON acid_event USING btree (sig_name);


--
-- Name: acid_event_sig_priority; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_sig_priority ON acid_event USING btree (sig_priority);


--
-- Name: acid_event_signature; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_signature ON acid_event USING btree (signature);


--
-- Name: acid_event_timestamp; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX acid_event_timestamp ON acid_event USING btree ("timestamp");


--
-- Name: base_users_usr_login; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX base_users_usr_login ON base_users USING btree (usr_login);


--
-- Name: icmp_type_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX icmp_type_idx ON icmphdr USING btree (icmp_type);


--
-- Name: ip_dst_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX ip_dst_idx ON iphdr USING btree (ip_dst);


--
-- Name: ip_src_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX ip_src_idx ON iphdr USING btree (ip_src);


--
-- Name: sig_class_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX sig_class_idx ON signature USING btree (sig_class_id);


--
-- Name: sig_class_name_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX sig_class_name_idx ON sig_class USING btree (sig_class_name);


--
-- Name: sig_name_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX sig_name_idx ON signature USING btree (sig_name);


--
-- Name: signature_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX signature_idx ON event USING btree (signature);


--
-- Name: tcp_dport_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX tcp_dport_idx ON tcphdr USING btree (tcp_dport);


--
-- Name: tcp_flags_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX tcp_flags_idx ON tcphdr USING btree (tcp_flags);


--
-- Name: tcp_sport_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX tcp_sport_idx ON tcphdr USING btree (tcp_sport);


--
-- Name: timestamp_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX timestamp_idx ON event USING btree ("timestamp");


--
-- Name: udp_dport_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX udp_dport_idx ON udphdr USING btree (udp_dport);


--
-- Name: udp_sport_idx; Type: INDEX; Schema: public; Owner: nac; Tablespace: 
--

CREATE INDEX udp_sport_idx ON udphdr USING btree (udp_sport);


--
-- Name: juezviolaciones; Type: TRIGGER; Schema: public; Owner: nac
--

CREATE TRIGGER juezviolaciones
    BEFORE INSERT OR UPDATE ON event
    FOR EACH ROW
    EXECUTE PROCEDURE juezviolaciones();


--
-- Name: public; Type: ACL; Schema: -; Owner: nac
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM nac;
GRANT ALL ON SCHEMA public TO nac;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

