<?
/***********************************************************************
 * Funciones para Iztaci NAC                                           *
 ***********************************************************************/


/************************************************************************
 * Funciones para procesamiento SQL
 */

/*
 * conectadb()
 *
 * Crea una conexion a nuestra base de datos
 */

function conectadb() {
   global $database, $usuario_bd, $password_bd;
   pg_connect("dbname=$database user=$usuario_bd password=$password_bd") or die("Couldn't Connect: " . pg_last_error());
}


/*
 * sql()
 *
 * Recibe un query, lo ejecuta y regresa los resultados, verificacion
 * de errores.
 */

function sql($query) 
{

   $resultado = pg_query ($query);
   if ( ! $resultado ) {
      print "<br><b>Ocurri&oacute; un error SQL:</b><br>\n<i>" . pg_last_error() . "</i><br>\n";
      print "<br><b>QUERY:</b> \"" . $query . "\"";
      var_dump (debug_backtrace());
      die;
   }

   return $resultado;
}

/*
 * DameRenglon()
 *
 * Recibe un resultado de query y devuelve el siguiente renglon en
 * el resultado. Es realmente una envoltura para no estar llamando
 * a pg_fetch_array siempre con los mismos argumentos.
 */

function DameRenglon($resultado) {
   return pg_fetch_array($resultado, NULL, PGSQL_ASSOC);
}

/*
 * Oportunidades()
 *
 * Regresa las oportunidades que le quedan a esta direccion IP
 *
 *
 */

function Oportunidades($ip) {

   global $max_oportunidades;

   $res = sql("SELECT oportunidades
               FROM   usuarios
               WHERE  id_usuario = '$ip'");

   /* Averiguemos cuantas oportunidades le quedan a este usuario */

   /* Ya tenemos una entrada para este usuario? */
   
   $oportunidades = 0;


   if (! $row = DameRenglon($res) ) {
   /* Si falta, la creamos */
      sql("INSERT INTO usuarios VALUES ('$ip',
                                        1,
                                        $max_oportunidades)");
      $oportunidades = $max_oportunidades;
   }
   else {
      $oportunidades = $row['oportunidades'];
   }

   return $oportunidades;

}

/*
 * ViolacionesActivas()
 *
 * Devuelve un resultado SQL con la lista de violaciones
 * activas para una direccion IP dada
 *
 */

function ViolacionesActivas($ip) {

$intip = ip2int($ip);

return sql("SELECT violaciones.signature,
                   sig_name,
                   ip_src,
                   ip_dst,
                   to_char (to_char(timestamp, 'YYYY-MM-DD, HH24:MI:SS')::timestamp at time zone 'UTC', 'DD/MM/YYY, HH24:MI') as timestamp,
                   id_violacion
            FROM violaciones, iphdr, signature, event, politicas
            WHERE id_castigo < 100
            AND violaciones.signature = politicas.signature
            AND iphdr.cid = violaciones.cid
            AND event.cid = violaciones.cid
            AND signature.sig_id = event.signature
            AND violaciones.sid = iphdr.sid
            AND violaciones.sid = event.sid
            AND violaciones.activa = 't'
            AND ( iphdr.ip_dst = $intip
            OR    iphdr.ip_src = $intip )");

}

/************************************************************************
 * Funciones miscelaneas
 */

function ip2int($ip) {


$ipArr    = explode('.', $ip);
return $ipArr[0] * 0x1000000
      + $ipArr[1] * 0x10000
      + $ipArr[2] * 0x100
      + $ipArr[3];

}


function int2ip($ipVal) {
        $ipArr = array(0 =>
                    floor(  $ipVal               / 0x1000000) );
        $ipVint   = $ipVal-($ipArr[0]*0x1000000); // for clarity
        $ipArr[1] = ($ipVint & 0xFF0000)  >> 16;
        $ipArr[2] = ($ipVint & 0xFF00  )  >> 8;
        $ipArr[3] =  $ipVint & 0xFF;
        $ipDotted = implode('.', $ipArr);
	return $ipDotted;
}

/*
 * AplicaCastigo()
 *
 * Recibe una violacion y aplica el castigo que le corresponde
 */

function AplicaCastigo($id_violacion, $ip) {

   global $max_oportunidades;


   /* Hay una entrada en la tabla de usuarios para esta direccion IP? */
   $rowusuario = DameRenglon(sql("SELECT *
                                  FROM usuarios
                                  WHERE id_usuario='$ip'"));

   /* Si la fila de regreso es NULL entonces         */
   /* no hay entrada para este usuario. Hagamos una. */

   if ( ! $rowusuario ) {
      sql("INSERT INTO usuarios VALUES ( '$ip', DEFAULT, $max_oportunidades)");
   }

   /* Buscamos el castigo que corresponde a   */
   /* esta signature y este tipo_usuario      */
   /* (El tipo "1" significa TODOS) */

   $rowtipo = DameRenglon(sql("SELECT usuarios.tipo_usuario,descripcion
                               FROM usuarios, tipos_usuarios
                               WHERE id_usuario='$ip'
                               AND   tipos_usuarios.tipo_usuario = usuarios.tipo_usuario"));

   $tipo_usuario = $rowtipo['tipo_usuario'];
   $descripcion_usuario = $rowtipo['descripcion'];

   $rescastigo = (sql("SELECT tipo_usuario,comando FROM politicas, castigos
                                  WHERE ( politicas.tipo_usuario = (SELECT tipo_usuario
                                                                    FROM usuarios
                                                                    WHERE id_usuario='$ip')
                                  OR  politicas.tipo_usuario = 1 )
                                  AND castigos.id_castigo = politicas.id_castigo
                                  AND   politicas.signature = (SELECT signature
                                                               FROM   violaciones
                                                               WHERE  id_violacion = $id_violacion)
                                  ORDER BY tipo_usuario DESC"));

   /* Marcamos la violacion como ejecutada */
   $ejecutada = TRUE;
   sql("UPDATE violaciones
        SET ejecutada = 't'
        WHERE id_violacion = $id_violacion");

   if ( ! DameRenglon($rescastigo) ) {
      print "No hay un castigo definido el tipo de usuario ($tipo_usuario - $descripcion_usuario) y violacion ($id_violacion)\n";
   } else {


      pg_result_seek ($rescastigo, 0);

      /* Puede haber varios castigos aplicables, los aplicamos en orden */
      

      while ( $rowcastigo = DameRenglon($rescastigo) ) {
         $comando = $rowcastigo['comando'];
   
   


         /* Buscamos el nombre de la signature para sustituirlo en el comando */
         $rowsig = DameRenglon(sql("SELECT sig_name,signature
                                    FROM signature,violaciones
                                    WHERE signature.sig_sid=violaciones.signature
                                    AND violaciones.id_violacion=$id_violacion"));

         $comando = str_replace ( "%s", $ip, $comando );
         $comando = str_replace ( "%d", "\"" . $rowsig['sig_name'] . " | " . $rowsig['signature'] . "\"", $comando );
         $retval = 0;
         print "Aplicando violacion ($id_violacion) para tipo de usuario ($tipo_usuario - $descripcion_usuario)\n";
         print "Ejecutando: \"$comando\"\n";
         passthru ( $comando, $retval );
   
         if ( $retval != 0 ) {
            /* Un valor de retorno 7 indica un error temporal */
            if ( $retval == 7 ) {
               print "Ejecucion diferida temporalmente, valor de retorno: $retval\n";
            }
            else {
               print "ERROR - valor de retorno: $retval\n";
            }
   
            /* Si alguno de los castigos fallo o fue diferido entonces */
            /* los tendremos que aplicar todos de nuevo despues. Por   */
            /* lo pronto marcamos la violacion como NO ejecutada       */

            $ejecutada = FALSE;
         }
   
      }

      if ( ! $ejecutada ) {
         /* Marcamos la violacion como NO ejecutada */
            sql("UPDATE violaciones
                 SET ejecutada = 'f'
                 WHERE id_violacion = $id_violacion");
      }

   }
}

?>
